pub fn insert_call_outcome_test(
interpreter: &mut Interpreter,
outcome: InterpreterResult,
return_memory_offset: Option<Range<usize>>,
)Available on crate features
__fuzzing only.Expand description
Insert a call outcome into the interpreter state (for testing call_with_interpreter).
Mimics revm-handler’s insert_call_outcome: pushes success indicator, copies return data to memory, and returns unspent gas.